Grepme
A library that provides utilities necessary for grep-like operations.
The crate is organised into a few focused modules:
Re-exports
pub use targets::ExpansionFailed;
A library that provides utilities necessary for grep-like operations.
The crate is organised into a few focused modules:
pub use targets::ExpansionFailed;